@@ -13,7 +13,7 @@ from twisted.internet.defer import inlineCallbacks, returnValue
 from . import widgets as w
 from . import DriverError
 from .tkutils import get_root
-from .misc import (createJSON, saveJSON, postJSON, startNodding,
+from .misc import (createJSON, isPoweredOn, saveJSON, postJSON, startNodding,
                    execCommand, isRunActive, jsonFromFits)
 
 if not six.PY3:
@@ -718,10 +718,14 @@ class InstPars(tk.LabelFrame):
 
         # allow posting if parameters are OK. update count and SN estimates too
         if status:
-            run_active = yield isRunActive(g)
+            try:
+                run_active = yield isRunActive(g)
+                powered_on = yield isPoweredOn(g)
+            except Exception as err:
+                g.clog.warn(str(err))
             if (g.cpars['hcam_server_on'] and g.cpars['eso_server_online'] and
                     g.observe.start['state'] == 'disabled' and
-                    not run_active):
+                    not run_active and powered_on):
                 g.observe.start.enable()
             g.count.update()
         else:
@@ -1168,7 +1172,7 @@ class RunPars(tk.LabelFrame):
                 ok = False
                 msg += 'Target name field cannot be blank\n'
 
-            if dtype == 'data caution' or \
+            if dtype == 'acquisition' or \
                dtype == 'data' or dtype == 'technical':
 
                 if self.prog_ob.ok():
@@ -1223,7 +1227,7 @@ class RunPars(tk.LabelFrame):
         g = get_root(self).globals
         self.filter.configure(state='normal')
         dtype = g.observe.rtype()
-        if dtype == 'data caution' or dtype == 'data' or dtype == 'technical':
+        if dtype == 'acquisition' or dtype == 'data' or dtype == 'technical':
             self.prog_ob.configure(state='normal')
             self.pi.configure(state='normal')
             self.target.enable()
@@ -1535,7 +1539,7 @@ class RunType(w.Select):
     Start button should be disabled until an option is made from this dropdown.
     """
     DTYPES = ('', 'data', 'acquire', 'bias', 'flat', 'dark', 'tech')
-    DVALS = ('', 'data', 'data caution', 'bias', 'flat', 'dark', 'technical')
+    DVALS = ('', 'data', 'acquisition', 'bias', 'flat', 'dark', 'technical')
 
     def __init__(self, master, start_button, checker=None):
         w.Select.__init__(self, master, 0, RunType.DTYPES, self.check)
@@ -1560,9 +1564,14 @@ class RunType(w.Select):
         else:
             self.start_button.run_type_set = True
             g = get_root(self).globals
-            run_active = yield isRunActive(g)
+            try:
+                run_active = yield isRunActive(g)
+                powered_on = yield isPoweredOn(g)
+            except Exception as err:
+                g.clog.warn(str(err))
             if (g.cpars['hcam_server_on'] and g.cpars['eso_server_online'] and
-                    g.observe.start['state'] == 'disabled' and not run_active):
+                    g.observe.start['state'] == 'disabled' 
+                    and not run_active and powered_on):
                 self.start_button.enable()
             g.rpars.check()
 
