@@ -102,7 +102,8 @@ def startNodding(g, data):
             yield session.call('hipercam.gtc.rpc.gtc.start_nodding')
         except Exception as err:
             g.clog.warn('Failed to stop dither server')
-            g.clog.warn(str(err))
+            msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+            g.clog.warn(msg)
             returnValue(False)
     returnValue(True)
 
@@ -118,7 +119,8 @@ def stopNodding(g):
             yield session.call('hipercam.gtc.rpc.gtc.stop_nodding')
         except Exception as err:
             g.clog.warn('Failed to stop dither server')
-            g.clog.warn(str(err))
+            msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+            g.clog.warn(msg)
             returnValue(False)
     returnValue(True)
 
@@ -179,7 +181,8 @@ def postJSON(g, data):
     try:
         ok, status_msg = yield session.call('hipercam.ngc.rpc.load_setup', data)
     except Exception as err:
-        ok, status_msg = False, str(err)
+        status_msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+        ok = False
 
     if not ok:
         g.clog.warn('Server response was not OK')
@@ -195,7 +198,8 @@ def postJSON(g, data):
             yield session.call('hipercam.gtc.rpc.load_nod_pattern', ra_offsets, dec_offsets)
             ok = True
         except Exception as err:
-            ok, status_msg = False, str(err)
+            status_msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+            ok = False
 
         if not ok:
             g.clog.warn('Offset Server response was not OK')
@@ -236,8 +240,10 @@ def createJSON(g, full=True):
                 try:
                     telpars = yield session.call('hipercam.gtc.rpc.get_telescope_pars')
                     data['gtc_headers'] = telpars
-                except Exception:
+                except Exception as err:
                     g.clog.warn('cannot get GTC headers from telescope server')
+                    msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+                    g.clog.warn(msg)
     returnValue(data)
 
 
@@ -351,7 +357,8 @@ def insertFITSHDU(g):
         yield session.call('hipercam.ngc.rpc.add_hdu', fd.getvalue(), run_number)
     except Exception as err:
         g.clog.warn('insertFITSHDU failed')
-        g.clog.warn(str(err))
+        msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+        g.clog.warn(msg)
     returnValue(True)
 
 
@@ -406,7 +413,8 @@ def execCommand(g, command, timeout=10):
             returnValue(False)
     except Exception as err:
         g.clog.warn('execCommand failed')
-        g.clog.warn(str(err))
+        msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+        g.clog.warn(msg)
 
     returnValue(False)
 
@@ -425,7 +433,8 @@ def isRunActive(g):
         try:
             response = yield session.call('hipercam.ngc.rpc.summary')
         except Exception as err:
-            raise DriverError('isRunActive error reading NGC status: ' + str(err))
+            msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+            raise DriverError('isRunActive error reading NGC status: ' + msg)
         tel = ReadNGCTelemetry(response)
 
         if not tel.ok:
@@ -434,6 +443,12 @@ def isRunActive(g):
             returnValue(False)
         elif tel.state == 'active':
             returnValue(True)
+        elif tel.state == 'error':
+            msg = """
+            NGC is in error state.
+            Try resetting it using 'start_hicam' and 'Power On'
+            """
+            raise DriverError('isRunActive error\n' + msg)
         else:
             raise DriverError('isRunActive error, state = ' + tel.state)
     else:
@@ -451,7 +466,8 @@ def isPoweredOn(g):
         try:
             response = yield session.call('hipercam.ngc.rpc.summary')
         except Exception as err:
-            raise DriverError('isPoweredOn error reading NGC status: ' + str(err))
+            msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+            raise DriverError('isPoweredOn error reading NGC status: ' + msg)
 
         tel = ReadNGCTelemetry(response)
         if not tel.ok:
@@ -476,7 +492,8 @@ def isOnline(g):
         try:
             msg, ok = yield session.call('hipercam.ngc.rpc.status')
         except Exception as err:
-            raise DriverError('isOnline error: ' + str(err))
+            msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+            raise DriverError('isOnline error: ' + msg)
 
         if not ok:
             raise DriverError('isOnline error: ' + msg)
@@ -528,7 +545,8 @@ def getRunNumber(g):
     try:
         response = yield session.call('hipercam.ngc.rpc.summary')
     except Exception as err:
-        raise DriverError('isRunActive error reading NGC status: ' + str(err))
+        msg = err.error_message() if hasattr(err, 'error_message') else str(err)
+        raise DriverError('isRunActive error reading NGC status: ' + msg)
     tel = ReadNGCTelemetry(response)
     if tel.ok:
         returnValue(tel.run)
